@@ -1,9 +1,10 @@
-__version__ = "0.2.7.1"
+__version__ = "0.2.8"
 
 from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
 from .progress_bar import probar
 from .performance import MeasureTime
+from .async_api import ConcurrentRequester
 # from .decorators import benchmark
 # from .string.color_string import rgb_string
 # from .functions.core import clamp, topk, dict_topk
